digraph {
	graph [bgcolor=white fontcolor=black fontname=Helvetica fontsize=16 rankdir=LR]
	node [color=white fillcolor=white fontcolor="#5e5d87" fontname=Helvetica shape=rectangle style=filled]
	edge [arrowhead=normal arrowsize=1 color=black fontcolor=black fontname=Helvetica fontsize=12 penwidth=3 style=dashed]
	compound=true newrank=true
	subgraph cluster_0 {
		graph [color="#cecdc9" label=<<B>term: 1F</B><BR/><FONT POINT-SIZE="10" COLOR="#6e6d6a">9 cr</FONT>> rank=same style=filled]
		"PHY 171+L" [label=<<font color="#6e6d6a"><sub>5</sub></font>   PHY 171+L>]
		"MTH 171" [label=<<font color="#6e6d6a"><sub>4</sub></font>   MTH 171>]
	}
	subgraph cluster_1 {
		graph [color="#cecdc9" label=<<B>term: 1S</B><BR/><FONT POINT-SIZE="10" COLOR="#6e6d6a">12 cr</FONT>> rank=same style=filled]
		"PHY 172+L" [label=<<font color="#6e6d6a"><sub>5</sub></font>   PHY 172+L>]
		"GE 104" [label=<<font color="#6e6d6a"><sub>3</sub></font>   GE 104>]
		"MTH 172" [label=<<font color="#6e6d6a"><sub>4</sub></font>   MTH 172>]
	}
	subgraph cluster_2 {
		graph [color="#cecdc9" label=<<B>term: 2F</B><BR/><FONT POINT-SIZE="10" COLOR="#6e6d6a">14 cr</FONT>> rank=same style=filled]
		"GE 204" [label=<<font color="#6e6d6a"><sub>3</sub></font>   GE 204>]
		"CHM 145+L" [label=<<font color="#6e6d6a"><sub>5</sub></font>   CHM 145+L>]
		"MTH 322" [label=<<font color="#6e6d6a"><sub>3</sub></font>   MTH 322>]
		"MTH 271" [label=<<font color="#6e6d6a"><sub>3</sub></font>   MTH 271>]
	}
	subgraph cluster_3 {
		graph [color="#cecdc9" label=<<B>term: 2S</B><BR/><FONT POINT-SIZE="10" COLOR="#6e6d6a">10 cr</FONT>> rank=same style=filled]
		"GE 205" [label=<<font color="#6e6d6a"><sub>3</sub></font>   GE 205>]
		"MTH 353" [label=<<font color="#6e6d6a"><sub>3</sub></font>   MTH 353>]
		"GE 206+7" [label=<<font color="#6e6d6a"><sub>4</sub></font>   GE 206+7>]
	}
	subgraph cluster_4 {
		graph [color="#cecdc9" label=<<B>term: 3F</B><BR/><FONT POINT-SIZE="10" COLOR="#6e6d6a">17 cr</FONT>> rank=same style=filled]
		"ME 315" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 315>]
		"ME 316" [label=<<font color="#6e6d6a"><sub>1</sub></font>   ME 316>]
		"ME 303" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 303>]
		"ME 300+L" [label=<<font color="#6e6d6a"><sub>4</sub></font>   ME 300+L>]
		"ME 340" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 340>]
		"ME 345" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 345>]
	}
	subgraph cluster_5 {
		graph [color="#cecdc9" label=<<B>term: 3S</B><BR/><FONT POINT-SIZE="10" COLOR="#6e6d6a">13 cr</FONT>> rank=same style=filled]
		"ME 308+9" [label=<<font color="#6e6d6a"><sub>4</sub></font>   ME 308+9>]
		"ME 370" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 370>]
		"ME 302" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 302>]
		"ME 350" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 350>]
	}
	subgraph cluster_6 {
		graph [color="#cecdc9" label=<<B>term: 4F</B><BR/><FONT POINT-SIZE="10" COLOR="#6e6d6a">12 cr</FONT>> rank=same style=filled]
		"ME 430+L" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 430+L>]
		"ME Elective I" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME Elective I>]
		"ME 498" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 498>]
		"ME 410" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 410>]
	}
	subgraph cluster_7 {
		graph [color="#cecdc9" label=<<B>term: 4S</B><BR/><FONT POINT-SIZE="10" COLOR="#6e6d6a">12 cr</FONT>> rank=same style=filled]
		"GE 359" [label=<<font color="#6e6d6a"><sub>3</sub></font>   GE 359>]
		"ME Elective III" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME Elective III>]
		"ME 499+L" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME 499+L>]
		"ME Elective II" [label=<<font color="#6e6d6a"><sub>3</sub></font>   ME Elective II>]
	}
	"PHY 171+L" -> "PHY 172+L" [lhead=cluster_1 ltail=cluster_0 style=invis]
	"PHY 172+L" -> "GE 204" [lhead=cluster_2 ltail=cluster_1 style=invis]
	"GE 204" -> "GE 205" [lhead=cluster_3 ltail=cluster_2 style=invis]
	"GE 205" -> "ME 315" [lhead=cluster_4 ltail=cluster_3 style=invis]
	"ME 315" -> "ME 308+9" [lhead=cluster_5 ltail=cluster_4 style=invis]
	"ME 308+9" -> "ME 430+L" [lhead=cluster_6 ltail=cluster_5 style=invis]
	"ME 430+L" -> "GE 359" [lhead=cluster_7 ltail=cluster_6 style=invis]
	"PHY 172+L" -> "ME 315" [color="#803e75" style=solid]
	"ME 315" -> "ME 316" [color="#ff6800" style=dashed]
	"ME 345" -> "ME 316" [color="#a6bdd7" style=dashed]
	"GE 205" -> "ME 308+9" [color="#c10020" style=solid]
	"GE 206+7" -> "ME 308+9" [color="#cea262" style=solid]
	"ME 345" -> "ME 370" [color="#817066" style=solid]
	"GE 205" -> "ME 370" [color="#007d34" style=solid]
	"MTH 353" -> "ME 370" [color="#f6768e" style=dashed]
	"GE 206+7" -> "ME 303" [color="#00538a" style=solid]
	"CHM 145+L" -> "ME 303" [color="#ff7a5c" style=solid]
	"GE 206+7" -> "ME 302" [color="#53377a" style=solid]
	"MTH 171" -> "GE 204" [color="#ff8e00" style=solid]
	"PHY 171+L" -> "GE 204" [color="#b32851" style=solid]
	"GE 204" -> "GE 205" [color="#f4c800" style=solid]
	"ME 340" -> "ME 430+L" [color="#7f180d" style=solid]
	"ME 308+9" -> "ME 430+L" [color="#93aa00" style=solid]
	"MTH 322" -> "ME 430+L" [color="#593315" style=solid]
	"GE 206+7" -> "ME 300+L" [color="#f13a13" style=solid]
	"ME 302" -> "ME 498" [color="#232c16" style=solid]
	"ME 370" -> "ME 498" [color="#ffb300" style=solid]
	"ME 430+L" -> "ME 498" [color="#803e75" style=dashed]
	"MTH 172" -> "PHY 172+L" [color="#ff6800" style=dashed]
	"MTH 171" -> "PHY 171+L" [color="#a6bdd7" style=dashed]
	"MTH 171" -> "GE 104" [color="#c10020" style=solid]
	"PHY 171+L" -> "GE 104" [color="#cea262" style=solid]
	"ME 498" -> "ME 499+L" [color="#817066" style=solid]
	"MTH 172" -> "MTH 322" [color="#007d34" style=solid]
	"CHM 145+L" -> "ME 340" [color="#f6768e" style=solid]
	"PHY 172+L" -> "ME 340" [color="#00538a" style=solid]
	"MTH 322" -> "ME 340" [color="#ff7a5c" style=dashed]
	"MTH 172" -> "MTH 271" [color="#53377a" style=solid]
	"MTH 172" -> "MTH 353" [color="#ff8e00" style=solid]
	"MTH 322" -> "ME 345" [color="#b32851" style=solid]
	"PHY 172+L" -> "ME 345" [color="#f4c800" style=solid]
	"MTH 171" -> "MTH 172" [color="#7f180d" style=solid]
	"GE 104" -> "ME 350" [color="#93aa00" style=solid]
	"GE 204" -> "GE 206+7" [color="#593315" style=solid]
	"GE 205" -> "ME 410" [color="#f13a13" style=solid]
	"MTH 322" -> "ME 410" [color="#232c16" style=solid]
}
